from tendenci.apps.perms.managers import TendenciBaseManager

class BoxManager(TendenciBaseManager):
    """
    Model Manager
    """
    pass
